[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Fuyu
A implementation of Fuyu from Adept in pytorch using Zeta primitives


[Blog paper code](https://www.adept.ai/blog/fuyu-8b)

# Appreciation
* Lucidrains
* Agorians
* Adept



# Install
`fuyu`

# Usage

# Architecture
image patches -> linear projection -> decoder llm

# Todo


# License
MIT

# Citations

